=========
CHANGELOG
=========

Neapolitan is still in **alpha** stage. It won't change much but I'm still
working out the fine details of the API.

The provided templates (in particular) will evolve as needed without notice
until we get closer to a resting place. If a change affects you, you can copy to
templates as were to your own project, and go from there.

Version numbers correspond to git tags. Please use the compare view on GitHub
for full details. Until we're further along, I will just note the highlights
here:

23.8
====

* Adjusted object-view action links to include the detail view link.

23.7
====

To 23.7: initial exploratory work.
